Introduction
============

AsyncAmqp library is a pure-Python implementation of the AMQP 0.9.1 protocol using anyio_.

.. _anyio: https://github.com/agronholm/anyio/

Prerequisites
-------------

AsyncAmqp works with python >= 3.7 using asyncio, trio or curio.

Installation
------------

You can install the most recent async_amqp release from pypi using pip or easy_install:

 .. code-block:: shell

    pip install async_amqp
